@@ -61,35 +61,26 @@ def indent_html(rawcode: str, config: Config) -> str:
             tmp = (indent * indent_level) + item + "\n"
 
         # if a one-line, inline tag, just process it, only if line starts w/ it
+        # or if it is trailing text
         elif (
-            re.findall(
-                rf"(<({slt_html})>)(.*?)(</(\2)>[^<]*?$)",
-                item,
-                re.IGNORECASE | re.VERBOSE | re.MULTILINE,
-            )
-            or re.findall(
-                re.compile(
-                    rf"(<({slt_html})\b.+?>)(.*?)(</(\2)>[^<]*?$)",
+            (
+                re.findall(
+                    rf"""^(?:[^<\s].*?)? # start of a line, optionally with some text
+                    (?:
+                        (?:<({slt_html})>)(?:.*?)(?:</(?:\1)>[ \t]*?) # <span>stuff</span> >>>> match 1
+                       |(?:<({slt_html})\b[^>]+?>)(?:.*?)(?:</(?:\2)>[ \t]*?) # <span stuff>stuff</span> >>> match 2
+                       |(?:<(?:{always_self_closing_html})\b[^>]*?/?>[ \t]*?) # <img stuff />
+                       |(?:<(?:{slt_html})\b[^>]*?/>[ \t]*?) # <img />
+                       |(?:{{%[ ]*?({slt_template})[ ]+?.*?%}})(?:.*?)(?:{{%[ ]+?end(\3)[ ]+?.*?%}}[ \t]*?) # >>> match 3
+                    )
+                    +?[^<]*?$ # with no other tags following until end of line
+                """,
+                    item,
                     re.IGNORECASE | re.VERBOSE | re.MULTILINE,
-                ),
-                item,
+                )
             )
-            or re.findall(
-                rf"^({{%[ ]*?({slt_template})[ ]+?.*?%}})(.*?)({{%[ ]+?end(\2)[ ]+?.*?%}})",
-                item,
-                re.IGNORECASE | re.MULTILINE | re.VERBOSE,
-            )
-            or re.findall(
-                rf"(<({slt_html})\b.*?/>)", item, flags=re.IGNORECASE | re.VERBOSE
-            )
-            or re.findall(
-                re.compile(
-                    rf"(<({always_self_closing_html})\b.*?/?>)",
-                    re.IGNORECASE | re.VERBOSE,
-                ),
-                item,
-            )
-        ) and is_block_raw is False:
+            and is_block_raw is False
+        ):
             tmp = (indent * indent_level) + item + "\n"
 
         # if unindent, move left
@@ -101,6 +92,17 @@ def indent_html(rawcode: str, config: Config) -> str:
             )
             and is_block_raw is False
             and not is_safe_closing_tag(config, item)
+            # and not ending in a slt like <span><strong></strong>.
+            and not re.findall(
+                rf"(<({slt_html})>)(.*?)(</(\2)>[^<]*?$)",
+                item,
+                re.IGNORECASE | re.VERBOSE | re.MULTILINE,
+            )
+            and not re.findall(
+                rf"(<({slt_html})\\b[^>]+?>)(.*?)(</(\2)>[^<]*?$)",
+                item,
+                re.IGNORECASE | re.VERBOSE | re.MULTILINE,
+            )
         ):
             # block to catch inline block followed by a non-break tag
             if (
@@ -112,7 +114,7 @@ def indent_html(rawcode: str, config: Config) -> str:
                     )
                     or re.findall(
                         re.compile(
-                            rf"(^<({slt_html})\b.+?>)(.*?)(</(\2)>)",
+                            rf"(^<({slt_html})\b[^>]+?>)(.*?)(</(\2)>)",
                             re.IGNORECASE | re.VERBOSE | re.MULTILINE,
                         ),
                         item,
@@ -148,6 +150,7 @@ def indent_html(rawcode: str, config: Config) -> str:
             )
             and is_block_raw is False
         ):
+
             tmp = (indent * indent_level) + item + "\n"
             indent_level = indent_level + 1
 
