@@ -206,13 +206,13 @@ class Config:
         format_css: bool = False,
         format_js: bool = False,
         configuration: Optional[str] = None,
+        statistics: bool = False,
     ):
 
         self.reformat = reformat
         self.check = check
         self.lint = lint
         self.warn = warn
-        self.stdin = "-" in src
 
         self.project_root = find_project_root(Path(src))
 
@@ -262,6 +262,9 @@ class Config:
         # ignore is based on input and also profile
         self.ignore: str = str(ignore or djlint_settings.get("ignore", ""))
 
+        self.files: Optional[List[str]] = djlint_settings.get("files", None)
+        self.stdin = "-" in src and self.files is None
+
         # codes to exclude
         profile_dict: Dict[str, List[str]] = {
             "html": ["D", "J", "T", "N", "M"],
@@ -304,6 +307,8 @@ class Config:
             )
         )
 
+        self.statistics = statistics
+
         # base options
         default_indent = 4
         if not indent:
@@ -744,18 +749,29 @@ class Config:
         """
         )
 
+        # either a template tag at the start of a line,
+        # a html tag at the start of a line,
+        # or an html tag as the end of a line.
+        # Nothing in between!
         self.tag_unindent: str = (
             r"""
                 ^
                 """
             + self.template_unindent
             + """
-            | (?:</
+            | (?:^</
                 (?:
                     """
             + self.indent_html_tags
             + """
                 )\\b
               )
+            | (?:</
+                (?:
+                    """
+            + self.indent_html_tags
+            + """
+                )>$
+              )
         """
         )
